@@ -8,20 +8,26 @@ class NosePlugin(NosePluginBase):
     name = 'noselog'
     def options(self, parser, env=os.environ):
         super(NosePlugin, self).options(parser, env)
-        parser.add_option("--noselog-file", dest="outputfile", default="-")
+        parser.add_option("--noselog-file", dest="outputfiles", default=[], action="append",
+                          help="Output files to log to. '-' means stderr. Can be specified multiple times.")
         parser.add_option("--noselog-level", dest="level", default="DEBUG")
 
     def configure(self, options, conf):
         super(NosePlugin, self).configure(options, conf)
         if not self.enabled:
             return
-        if options.outputfile == "-":
-            handler = logging.StreamHandler(sys.stderr)
-        else:
-            handler = logging.FileHandler(options.outputfile)
-        handler.setLevel(self._get_levelno(options.level))
-        handler.setFormatter(logging.Formatter("%(asctime)s %(levelname)s -- %(message)s"))
-        logging.getLogger().addHandler(handler)
+        outputfiles = options.outputfiles
+        if not outputfiles:
+            outputfiles = ["-"]
+
+        for output_file_name in set(outputfiles):
+            if output_file_name == "-":
+                handler = logging.StreamHandler(sys.stderr)
+            else:
+                handler = logging.FileHandler(output_file_name)
+            handler.setLevel(self._get_levelno(options.level))
+            handler.setFormatter(logging.Formatter("%(asctime)s %(levelname)s -- %(message)s"))
+            logging.getLogger().addHandler(handler)
     def _get_levelno(self, level):
         if isinstance(level, Number):
             return level
@@ -29,7 +35,3 @@ class NosePlugin(NosePluginBase):
             if level_name == level:
                 return levelno
         raise LookupError("Level name not found")
-
-        
-
-
